==> aws-java-sdk-osgi-1.9.40-sources.jar: com/amazonaws/services/elasticbeanstalk/model/transform/InsufficientPrivilegesExceptionUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.elasticbeanstalk.model.transform;

import org.w3c.dom.Node;

import com.amazonaws.AmazonServiceException;
import com.amazonaws.util.XpathUtils;
import com.amazonaws.transform.StandardErrorUnmarshaller;

import com.amazonaws.services.elasticbeanstalk.model.InsufficientPrivilegesException;

public class InsufficientPrivilegesExceptionUnmarshaller extends StandardErrorUnmarshaller {

    public InsufficientPrivilegesExceptionUnmarshaller() {
        super(InsufficientPrivilegesException.class);
    }

    public AmazonServiceException unmarshall(Node node) throws Exception {
        // Bail out if this isn't the right error code that this
        // marshaller understands.
        String errorCode = parseErrorCode(node);
        if (errorCode == null || !errorCode.equals("InsufficientPrivilegesException"))
            return null;

        InsufficientPrivilegesException e = (InsufficientPrivilegesException)super.unmarshall(node);
        
        return e;
    }
}

==> aws-java-sdk-osgi-1.10.25-sources.jar: com/amazonaws/services/elasticbeanstalk/model/transform/InsufficientPrivilegesExceptionUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticbeanstalk.model.transform;

import org.w3c.dom.Node;

import com.amazonaws.AmazonServiceException;
import com.amazonaws.util.XpathUtils;
import com.amazonaws.transform.StandardErrorUnmarshaller;

import com.amazonaws.services.elasticbeanstalk.model.InsufficientPrivilegesException;

public class InsufficientPrivilegesExceptionUnmarshaller extends
        StandardErrorUnmarshaller {

    public InsufficientPrivilegesExceptionUnmarshaller() {
        super(InsufficientPrivilegesException.class);
    }

    @Override
    public AmazonServiceException unmarshall(Node node) throws Exception {
        // Bail out if this isn't the right error code that this
        // marshaller understands
        String errorCode = parseErrorCode(node);
        if (errorCode == null
                || !errorCode.equals("InsufficientPrivilegesException"))
            return null;

        InsufficientPrivilegesException e = (InsufficientPrivilegesException) super
                .unmarshall(node);

        return e;
    }
}
